@@ -58,7 +58,7 @@
 
 #define XSL_URL DATADIR"/msa/drivers/vkontakte/make_url.xsl"
 #define XSL_CONFIG_DIR DATADIR"/msa/drivers/vkontakte/"
-#define AUTH_URL "http://vkontakte.ru/login.php?app=1899304&layout=touch&type=touch&settings=15615"
+#define AUTH_URL "http://vkontakte.ru/login.php?app=1899304&layout=touch&type=browser&settings=15615"
 #define NOT_ESCAPE "!\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[]^_`abcdefghijklmnopqrstuvwxyz{|}~"
 
 
@@ -77,7 +77,8 @@ CTF_TEST_DATA_FILE_NAME_DECL;
 
 int counter = 0;
 int max_count = 0;
-static int global_temp = 0;
+static int global_req = 0;
+static int global_get = 0;
 int attempts = 0;
 int captch = 0;
 
@@ -480,9 +481,9 @@ int vk_req(xmlDocPtr reqXml, xmlDocPtr* doc, const struct msa_module* info)
     info_proxy = info->proxy;
     info_port = info->port;
 
-    global_temp++;
+    global_req++;
     
-    g_print("IN VK_REQ!!! %d\n", global_temp);
+    msa_debug("IN VK_REQ!!! %d\n", global_req);
     counter = 0;
     msa_xmlDocDump(stdout, reqXml);
 
@@ -794,8 +795,8 @@ int info_message(char* code, xmlDocPtr doc, char* message, int type)
  */
 int http_get(const char* url, const char* proxy, int port, char** header, gchar** body, int* data_size)
 {
-    global_temp++;    
-    g_print("IN HTTP GET!!! %d\n", global_temp);
+    global_get++;    
+    msa_debug("IN HTTP GET!!! %d\n", global_get);
 
     CURL* c;
     long code;
@@ -851,7 +852,7 @@ int http_get(const char* url, const char* proxy, int port, char** header, gchar*
         *header = g_strdup(chunk2.memory);
     }
 
-    g_print("HEADER  %s\n", chunk2.memory);
+    msa_debug("HEADER  %s\n", chunk2.memory);
     if(chunk2.memory)
         free(chunk2.memory);
 
