@@ -84,67 +84,46 @@
 #define BOOLEAN "boolean"
 #define NUMBER "number"
 #define NAME "name"
+#define LOGIN "login"
+#define PASSWORD "password"
+
+gchar *info_proxy;
+gint info_port;
 
 struct MemoryStruct {
     char* memory;
     size_t size;
 };
 
-gchar *info_proxy;
-gint info_port;
-
-#define LOGIN "login"
-#define PASSWORD "password"
-
-/**
- * Allocate memory
- *
- * @param ptr - pointer
- * @param size - size of data
-* @return 0 on success or 1 otherwise.
+/*
+ * Struct contains information of file for upload.
  */
+struct UpFile {
+    gchar *name;
+    gchar *file_path;
+    gchar *file_name;
+};
+
+void upfile_remove(struct UpFile *file);
 void* myrealloc(void* ptr, size_t size);
-
-extern int init_event_manager(int time);
-
-/**
- * Authorization (get remixsid and remixmid for future requests)
- *
- * @param cp - current profile
- * @return 0 on success or 1 otherwise.
- */
 int authorize(struct ProfileData *cp);
 int initialization(struct ProfileData *cp);
-int vk_req(xmlDocPtr reqXml, xmlDocPtr doc, const struct msa_module* info);
+int vk_req(xmlDocPtr reqXml, xmlDocPtr* doc, const struct msa_module* info);
 xmlChar* get_req_class(xmlDocPtr reqXml);
 xmlChar* get_req_function(xmlDocPtr reqXml);
-int captcha_message(xmlDocPtr doc, xmlDocPtr reqXml);
-int http_get(const char* url, const char* proxy, const int port, char** header, gchar** body);
-int http_upload_photo(const char* url, const char* proxy, const int port, char** header, gchar** body, struct ProfileData *cp, char* file, char* file_name);
+int http_get(const char* url, const char* proxy, const int port, char** header, gchar** body, int* data_size);
+int http_upload_file(const char* url, const char* proxy, const int port, char** header, gchar** body, struct ProfileData *cp, struct UpFile *file);
 int http_post(const char* url, const char* proxy, const int port, char* post_data, char** header, char** body, struct curl_slist** cookies);
-
-/**
- * Perform request
- *
- * @param reqXml - request
- * @param doc - response
- * @param cp - current profile
-* @return 0 on success or 1 otherwise.
- */
-int make_request(xmlDocPtr reqXml, xmlDocPtr doc, struct ProfileData *cp);
-int read_message(xmlDocPtr reqXml, char* remixmid, char* remixsid);
-gchar* make_url(xmlDocPtr reqXml, char* remixmid, char* remixsid, struct ProfileData *cp);
 int get_settings(xmlDocPtr doc, const struct ProfileData *cp);
-
-/**
- * Set settings in to current profile
- *
- * @param reqXml - request
- * @param cp - current profile
- * @return 0 on success or 1 otherwise.
- */
 int set_settings(xmlDocPtr reqXml, struct ProfileData *cp);
 int info_message(char* code, xmlDocPtr doc, char* message, int type);
 xmlXPathObject* xpath(char* req, xmlDocPtr doc);
 xmlNodePtr xpath_get_node(char* path, xmlDocPtr doc);
+
+int parse_auth(struct ProfileData *pr, char *back_url);
+xmlDocPtr apply_parser(xmlDocPtr request, gchar* parser, struct ProfileData *pr);
+int process_request(struct ProfileData *pr, xmlDocPtr request, xmlDocPtr* response);
+int process_inner_request(struct ProfileData *pr, xmlDocPtr inner_req);
+int save_file (xmlDocPtr reqXml, char* data, int data_size);
+int close_tags(gchar* data);
 #endif
