@@ -28,27 +28,29 @@
 #include <libxml/tree.h>
 #include <libxml/parser.h>
 
-
+/*
+//deprecated definitions. should be removed.
 #define VK_ID "vkontakte"
-//#define UI_ID "ui"
-//#define DB_ID "db"
-//#define MYSPACE_ID "myspace"
-//#define DRV_MANAGER_ID "drv_manager"
+#define UI_ID "ui"
+#define DB_ID "db"
+#define MYSPACE_ID "myspace"
+#define DRV_MANAGER_ID "drv_manager"
 #define HANDLER_ID "handler"
 #define KERNEL_ID "kernel"
-//#define TEST_ID "test_module" // id test module :))  
+#define TEST_ID "test_module" // id test module :))  
 
-//#define TARGET_TAG "TargetID"
-//#define TARGET_TAG_ORDER_ATTR "orderNumber"
-//#define TARGET_TAG_XPATH "//TransitData/TargetID"
-//#define SOURCE_TAG_XPATH "//TransitData/SourceID"
-//#define REQUEST_TAG_XPATH "//TransitData/Content/Request"
-//#define RESPONSE_TAG_XPATH "//TransitData/Content/Response"
-//#define REQUEST_PARAMS_TAG_XPATH "//TransitData/Content/Request/Params"
-//#define RESPONSE_PARAMS_TAG_XPATH "//TransitData/Content/Response/Params"
+#define TARGET_TAG "TargetID"
+#define TARGET_TAG_ORDER_ATTR "orderNumber"
+#define TARGET_TAG_XPATH "//TransitData/TargetID"
+#define SOURCE_TAG_XPATH "//TransitData/SourceID"
+#define REQUEST_TAG_XPATH "//TransitData/Content/Request"
+#define RESPONSE_TAG_XPATH "//TransitData/Content/Response"
+#define REQUEST_PARAMS_TAG_XPATH "//TransitData/Content/Request/Params"
+#define RESPONSE_PARAMS_TAG_XPATH "//TransitData/Content/Response/Params"
+*/
 
-//FIXME use in ui.c 
-//#define PARAMS_TAG_XPATH "//TransitData/Content/Response/Params/array"
+/*FIXME use in ui.c */
+#define PARAMS_TAG_XPATH "//TransitData/Content/Response/Params/array"
 
 #define CLASS_PROFILE "profile"
 #define GET_PROFILE "getProfile"
@@ -104,6 +106,11 @@
 #define DRV_MESS_READ_CODE "415"
 #define DRV_FRIEND_DEL_CODE "414"
 #define DRV_PHOTO_UPLOAD_CODE "420"
+#define DRV_AUTH_SUCCESS_CODE "430"
+#define DRV_AUTH_FAILED_CODE "431"
+#define DRV_FILE_DOWNLOAD_CODE "600"
+#define DRV_FILE_DOWNLOAD_ERROR_CODE "601"
+
 
 /** Driver message text **/
 #define DRV_SETT_ERROR "Unable to save settings"
@@ -112,6 +119,12 @@
 #define DRV_SETT_SAVED "Settings saved"
 #define L10N_DRV_SETT_SAVED _("Settings saved")
 
+#define DRV_AUTH_SUCCESS "Authorization successful"
+#define L10N_DRV_AUTH_SUCCESS _("Authorization successful")
+
+#define DRV_AUTH_FAILED "Authorization failed"
+#define L10N_DRV_AUTH_FAILED _("Authorization failed")
+
 #define DRV_AUTH_ERROR "Authorization problem"
 #define L10N_DRV_AUTH_ERROR _("Authorization problem")
 
@@ -157,6 +170,12 @@
 #define DRV_PHOTO_UPLOAD "Photo uploaded"
 #define L10N_DRV_PHOTO_UPLOAD _("Photo uploaded")
 
+#define DRV_FILE_DOWNLOAD "File downloaded"
+#define L10N_DRV_FILE_DOWNLOAD _("File downloaded")
+
+#define DRV_FILE_DOWNLOAD_ERROR "Can't download file"
+#define L10N_DRV_FILE_DOWNLOAD_ERROR _("Can't download file")
+
 /* Entity names */
 #define FIRST_NAME "FirstName"
 #define L10N_FIRST_NAME _("FirstName")
